@@ -45,11 +45,9 @@ static const char *gdm_helpers[] = {
 	"color",
 	"keyboard",
 	"media-keys",
-	"orientation",
 	"power",
 	"smartcard",
 	"sound",
-	"xrandr",
 	"xsettings"
 };
 
